@@ -58,8 +58,8 @@ class PrimitiveTypes(object):
             self.__encoder = lambda len, val: struct.pack('%dd' % len, *val)
             self.__prepare = lambda val: [float(x) for x in val.split(",")]
         elif (type_name == "FLOAT"):
-            self.__decoder = lambda len, val: struct.unpack('%fd' % len, val)
-            self.__encoder = lambda len, val: struct.pack('%fd' % len, *val)
+            self.__decoder = lambda len, val: struct.unpack('%df' % len, val)
+            self.__encoder = lambda len, val: struct.pack('%df' % len, *val)
             self.__prepare = lambda val: [float(x) for x in val.split(",")]
         elif (type_name == "INT8"):
             self.__decoder = lambda len, val: struct.unpack('%db' % len, val)
