@@ -252,7 +252,7 @@ class Subscription(object):
 
         return False
 
-    def _update(self, sub_msg, len):
+    def _updateProtocol0(self, sub_msg, len):
         if sub_msg:
             counter = 0
             for param in self.__info.params:
@@ -271,5 +271,25 @@ class Subscription(object):
                 for observer in self.__observer_list:
                     self.__pool.submit(observer, value)
 
+    def _updateProtocol1(self, sub_msg, len):
+        if sub_msg:
+            timestamp = timespec._make(unpack_from('QQ', sub_msg, 0))
+            counter = 0
+            for param in self.__info.params:
+                offset = param.offset
+                size = param.size
+                if (offset + size) <= len:
+
+                    value = self.__decoder[counter].decode(sub_msg[offset: offset + size],
+                                                           param.info.number_of_elements)
+                    self.__values[counter] = Parameter(timestamp, value)
+
+                counter += 1
+
+            if self.__observer_list:
+                value = self.__values[:]
+                for observer in self.__observer_list:
+                    self.__pool.submit(observer, value)
+
     def _failed(self):
         self.__future.set_result(None)
